/*
 Tecnisa - Tecnologia em Informtica

 Nome: Exclui contas exportadas

 Descrio:
 Procedimento para excluso de todas as contas ligadas  nota fiscal, boletos referentes as contas,
   baixas e movimentos bancarios

 Criao:
 24/04/2002 - Jenilson Ferreira de Andrade

 Chamada para criao
 @C:\Win_Prj\Sql\Oracle\1006_RECSTP_EXCLUI_CONTAREC_EXPORTADA.SQL;

 */

CREATE OR REPLACE PROCEDURE EXCLUI_CONTAREC_EXPORTADA
   (P_CDFILIAL    IN NOTAFISCAL.CDFILIAL%TYPE,
    P_NRLANCTONF  IN NOTAFISCAL.NRLANCTONF%TYPE)

AS
   V_CDREDUBX     BAIXARECEBIDA.CDREDUCONT%TYPE;
   V_NRMOVBANC    BAIXARECEBIDA.NRMOVBANC%TYPE;
   V_CDSEQUEXBA   MOVBANCARIO.CDSEQUEXBA%TYPE;
   V_NRSEQMOVREBA MOVBANCARIO.NRSEQMOVREBA%TYPE;
   V_CDFILIBAIREC BOLETRECEBER.CDFILIAL%TYPE;
   V_NRBAIXAREC   BOLETRECEBER.NRBAIXAREC%TYPE;

   V_VRAJBOLREC NUMBER;
   V_VRAJUCTREC NUMBER;
BEGIN
   FOR C_CNTREC IN (SELECT CDFILIAL,     NRLANCTONF,  NRSEQVENREC,
                           CDFILIBOLREC, NRLANBOLREC, CDEMPRESA,
                           CDFIMOVFLREC, DTMOVFLUXO,  IDMOVFLUXO,
                           CDCLASSFINA,  VRORIGREC,   NRPARCELAREC
                    FROM CONTARECEBER
                    WHERE CDFILIAL   = P_CDFILIAL AND
                          NRLANCTONF = P_NRLANCTONF
                    ORDER BY NRSEQVENREC) LOOP

      SELECT
         MAX(BR.CDFILIBAIREC),
         MAX(BR.NRBAIXAREC)
      INTO
         V_CDFILIBAIREC,
         V_NRBAIXAREC
      FROM BOLETRECEBER BR, CONTARECEBER CR
      WHERE
         (CR.CDFILIAL     = C_CNTREC.CDFILIAL)     AND
         (CR.NRLANCTONF   = C_CNTREC.NRLANCTONF)   AND
         (CR.NRSEQVENREC  = C_CNTREC.NRSEQVENREC)  AND
         (CR.NRPARCELAREC = C_CNTREC.NRPARCELAREC) AND
         (CR.CDFILIBOLREC = BR.CDFILIAL)           AND
         (CR.NRLANBOLREC  = BR.NRLANBOLREC);

      /* BUSCA TODOS OS BOLETOS LIGADOS A BAIXA  */
      FOR C_BOLETREC_BX IN (SELECT CDFILIAL,     NRLANBOLREC,
                                   CDFILIBAIREC, NRBAIXAREC
                            FROM BOLETRECEBER
                            WHERE (CDFILIBAIREC = V_CDFILIBAIREC) AND
                                  (NRBAIXAREC   = V_NRBAIXAREC)) LOOP

         FOR C_RATR IN (SELECT AJ.CDFILIAL,     AJ.NRLANBOLREC, AJ.CDAJUCTREC,
                               AJ.VRAJBOLREC,   CR.CDCLASSFINA, CR.CDEMPRESA,
                               CR.CDFIMOVFLREC, CR.DTMOVFLUXO,  CR.IDMOVFLUXO,
                               TA.IDAJUCTREC,   CR.IDSTATREC,
                               DECODE(MAX(BR.VRBOLREC), 0, 0,
                                     (MAX(AJ.VRAJBOLREC) * SUM(CR.VRATUAREC))/ MAX(BR.VRBOLREC)) VRRATAJBOLREC
                        FROM CONTARECEBER  CR, BOLETRECEBER BR,
                             TIPOAJRECEBER TA, AJBOLREC   AJ
                        WHERE (AJ.CDFILIAL     = C_BOLETREC_BX.CDFILIAL)    AND
                              (AJ.NRLANBOLREC  = C_BOLETREC_BX.NRLANBOLREC) AND
                              (TA.CDAJUCTREC   = AJ.CDAJUCTREC)          AND
                              (BR.CDFILIAL     = AJ.CDFILIAL)            AND
                              (BR.NRLANBOLREC  = AJ.NRLANBOLREC)         AND
                              (CR.CDFILIBOLREC = BR.CDFILIAL)            AND
                              (CR.NRLANBOLREC  = BR.NRLANBOLREC)
                        GROUP BY
                           AJ.CDFILIAL,     AJ.NRLANBOLREC, AJ.CDAJUCTREC,
                           AJ.VRAJBOLREC,   CR.CDCLASSFINA, CR.CDEMPRESA,
                           CR.CDFIMOVFLREC, CR.DTMOVFLUXO,  CR.IDMOVFLUXO,
                           TA.IDAJUCTREC,   CR.IDSTATREC) LOOP

            IF C_RATR.IDAJUCTREC = 'D' THEN
               V_VRAJBOLREC := ROUND(C_RATR.VRRATAJBOLREC, 2);
            ELSE
               V_VRAJBOLREC := ROUND(C_RATR.VRRATAJBOLREC * -1, 2);
            END IF;
            /* - DESFAZ O FLUXO DE CAIXA -------------------------- */
            ATUALIZA_FLUXO_DE_CAIXA(C_RATR.CDEMPRESA,   C_RATR.CDFIMOVFLREC,
                                    C_RATR.DTMOVFLUXO,  C_RATR.IDMOVFLUXO,
                                    C_RATR.CDCLASSFINA, V_VRAJBOLREC, 0);

            DELETE FROM MOVFXAJBOLR
            WHERE CDFILIBOLREC = C_BOLETREC_BX.CDFILIAL    AND
                  NRLANBOLREC  = C_BOLETREC_BX.NRLANBOLREC AND
                  CDAJUCTREC   = C_RATR.CDAJUCTREC;

         END LOOP;

         DELETE FROM AJBOLREC
         WHERE CDFILIAL    = C_BOLETREC_BX.CDFILIAL AND
               NRLANBOLREC = C_BOLETREC_BX.NRLANBOLREC;
               
         FOR C_CNTREC_BX IN (SELECT CDFILIAL,     NRLANCTONF,  NRSEQVENREC,
                                    CDFILIBOLREC, NRLANBOLREC, CDEMPRESA,
                                    CDFIMOVFLREC, DTMOVFLUXO,  IDMOVFLUXO,
                                    CDCLASSFINA,  VRORIGREC,   NRPARCELAREC
                             FROM CONTARECEBER
                             WHERE CDFILIBOLREC = C_BOLETREC_BX.CDFILIAL AND  
                                   NRLANBOLREC  = C_BOLETREC_BX.NRLANBOLREC
                             ORDER BY NRSEQVENREC) LOOP
         
            FOR C_AJCTREC IN (SELECT AJ.CDFILIAL,    AJ.NRLANCTONF,   AJ.CDAJUCTREC,
                                     AJ.CDCLASSFINA, AJ.CDEMMFAJCNTR, AJ.CDFIMFAJCNTR,
                                     AJ.DTMOVFLUXO,  AJ.IDMOVFLUXO,   AJ.VRAJUSTEREC,
                                     TA.IDAJUCTREC,  AJ.NRSEQVENREC,  AJ.NRPARCELAREC
                              FROM AJCTRECEBER AJ, TIPOAJRECEBER TA
                              WHERE (AJ.CDFILIAL     = C_CNTREC_BX.CDFILIAL)     AND
                                    (AJ.NRLANCTONF   = C_CNTREC_BX.NRLANCTONF)   AND
                                    (AJ.NRSEQVENREC  = C_CNTREC_BX.NRSEQVENREC)  AND
                                    (AJ.NRPARCELAREC = C_CNTREC_BX.NRPARCELAREC) AND
                                    (TA.CDAJUCTREC   = AJ.CDAJUCTREC)) LOOP

               IF C_AJCTREC.IDAJUCTREC = 'D' THEN
                  V_VRAJUCTREC := ROUND(C_AJCTREC.VRAJUSTEREC, 2);
               ELSE
                  V_VRAJUCTREC := ROUND(C_AJCTREC.VRAJUSTEREC * -1, 2);
               END IF;
               /* - DESFAZ O FLUXO DE CAIXA -------------------------- */
               ATUALIZA_FLUXO_DE_CAIXA(C_AJCTREC.CDEMMFAJCNTR, C_AJCTREC.CDFIMFAJCNTR,
                                       C_AJCTREC.DTMOVFLUXO,   C_AJCTREC.IDMOVFLUXO,
                                       C_AJCTREC.CDCLASSFINA,  V_VRAJUCTREC, 0);

               DELETE FROM AJCTRECEBER
               WHERE (CDFILIAL     = C_AJCTREC.CDFILIAL)     AND
                     (NRLANCTONF   = C_AJCTREC.NRLANCTONF)   AND
                     (NRSEQVENREC  = C_AJCTREC.NRSEQVENREC)  AND
                     (NRPARCELAREC = C_AJCTREC.NRPARCELAREC);
            END LOOP;

            /* - DESFAZ O FLUXO DE CAIXA -------------------------- */
            ATUALIZA_FLUXO_DE_CAIXA(C_CNTREC_BX.CDEMPRESA,   C_CNTREC_BX.CDFIMOVFLREC,
                                    C_CNTREC_BX.DTMOVFLUXO,  C_CNTREC_BX.IDMOVFLUXO,
                                    C_CNTREC_BX.CDCLASSFINA, C_CNTREC_BX.VRORIGREC * -1, 0);
            DELETE FROM CONTARECEBER
            WHERE (CDFILIAL     = C_CNTREC_BX.CDFILIAL)     AND
                  (NRLANCTONF   = C_CNTREC_BX.NRLANCTONF)   AND
                  (NRSEQVENREC  = C_CNTREC_BX.NRSEQVENREC)  AND
                  (NRPARCELAREC = C_CNTREC_BX.NRPARCELAREC);
         END LOOP;

         DELETE FROM BOLETRECEBER
         WHERE CDFILIAL    = C_BOLETREC_BX.CDFILIAL AND
               NRLANBOLREC = C_BOLETREC_BX.NRLANBOLREC;
      END LOOP;

      IF (NOT V_NRBAIXAREC IS NULL) THEN
         SELECT
            MAX(BX.CDREDUCONT),
            MAX(BX.NRMOVBANC)
         INTO
            V_CDREDUBX,
            V_NRMOVBANC
         FROM BAIXARECEBIDA BX
         WHERE
            (BX.CDFILIAL   = V_CDFILIBAIREC) AND
            (BX.NRBAIXAREC = V_NRBAIXAREC);

         SELECT
            MAX(CDSEQUEXBA),
            MAX(NRSEQMOVREBA)
         INTO
            V_CDSEQUEXBA,
            V_NRSEQMOVREBA
         FROM MOVBANCARIO
         WHERE
            (CDREDUCONT = V_CDREDUBX) AND
            (NRMOVBANC  = V_NRMOVBANC);

         DELETE FROM BAIXARECEBIDA
         WHERE
            (CDFILIAL   = V_CDFILIBAIREC) AND
            (NRBAIXAREC = V_NRBAIXAREC);

         IF (NOT V_CDSEQUEXBA   IS NULL) AND
            (NOT V_NRSEQMOVREBA IS NULL) THEN
            UPDATE MOVBANCARIO
            SET
               IDSTCONEXT   = 0,
               IDCONCBANC   = NULL,
               CDSEQUEXBA   = NULL,
               NRSEQMOVREBA = NULL
            WHERE
               (CDREDUCONT   = V_CDREDUBX)   AND
               (IDSTCONEXT   = '1')          AND
               (CDSEQUEXBA   = V_CDSEQUEXBA) AND
               (NRSEQMOVREBA = V_NRSEQMOVREBA);
         END IF;

         DELETE FROM MOVBANCARIO
         WHERE
            (CDREDUCONT = V_CDREDUBX) AND
            (NRMOVBANC  = V_NRMOVBANC);

         IF (NOT V_CDSEQUEXBA   IS NULL) AND
            (NOT V_NRSEQMOVREBA IS NULL) THEN
            UPDATE MOVREAL
            SET
               IDSTCONMVBAN = 0,
               IDCONCREAL   = NULL,
               NRMOVBARE    = NULL
            WHERE
               (CDREDUCONT   = V_CDREDUBX) AND
               (CDSEQUEXTR   = V_CDSEQUEXBA) AND
               (NRSEQMOVREAL = V_NRSEQMOVREBA);
         END IF;
      END IF;

      /* BUSCA TODAS OS BOLETOS QUE NO ESTO LIGADOS A BAIXA  */
      FOR C_BOLETREC_AB IN (SELECT CDFILIAL,     NRLANCTONF,  NRSEQVENREC,
                                   CDFILIBOLREC, NRLANBOLREC, CDEMPRESA,
                                   CDFIMOVFLREC, DTMOVFLUXO,  IDMOVFLUXO,
                                   CDCLASSFINA,  VRORIGREC,   NRPARCELAREC
                            FROM CONTARECEBER
                            WHERE (CDFILIBOLREC = C_CNTREC.CDFILIBOLREC) AND
                                  (NRLANBOLREC  = C_CNTREC.NRLANBOLREC)
                            ORDER BY NRSEQVENREC) LOOP

         FOR C_RATR IN (SELECT AJ.CDFILIAL,     AJ.NRLANBOLREC, AJ.CDAJUCTREC,
                               AJ.VRAJBOLREC,   CR.CDCLASSFINA, CR.CDEMPRESA,
                               CR.CDFIMOVFLREC, CR.DTMOVFLUXO,  CR.IDMOVFLUXO,
                               TA.IDAJUCTREC,   CR.IDSTATREC,
                               DECODE(MAX(BR.VRBOLREC), 0, 0,
                                     (MAX(AJ.VRAJBOLREC) * SUM(CR.VRATUAREC))/ MAX(BR.VRBOLREC)) VRRATAJBOLREC
                        FROM CONTARECEBER  CR, BOLETRECEBER BR,
                             TIPOAJRECEBER TA, AJBOLREC   AJ
                        WHERE (AJ.CDFILIAL     = C_BOLETREC_AB.CDFILIBOLREC) AND
                              (AJ.NRLANBOLREC  = C_BOLETREC_AB.NRLANBOLREC)  AND
                              (TA.CDAJUCTREC   = AJ.CDAJUCTREC)         AND
                              (BR.CDFILIAL     = AJ.CDFILIAL)           AND
                              (BR.NRLANBOLREC  = AJ.NRLANBOLREC)        AND
                              (CR.CDFILIBOLREC = BR.CDFILIAL)           AND
                              (CR.NRLANBOLREC  = BR.NRLANBOLREC)
                        GROUP BY
                           AJ.CDFILIAL,     AJ.NRLANBOLREC, AJ.CDAJUCTREC,
                           AJ.VRAJBOLREC,   CR.CDCLASSFINA, CR.CDEMPRESA,
                           CR.CDFIMOVFLREC, CR.DTMOVFLUXO,  CR.IDMOVFLUXO,
                           TA.IDAJUCTREC,   CR.IDSTATREC) LOOP

            IF C_RATR.IDAJUCTREC = 'D' THEN
               V_VRAJBOLREC := ROUND(C_RATR.VRRATAJBOLREC, 2);
            ELSE
               V_VRAJBOLREC := ROUND(C_RATR.VRRATAJBOLREC * -1, 2);
            END IF;
            /* - DESFAZ O FLUXO DE CAIXA -------------------------- */
            ATUALIZA_FLUXO_DE_CAIXA(C_RATR.CDEMPRESA,   C_RATR.CDFIMOVFLREC,
                                    C_RATR.DTMOVFLUXO,  C_RATR.IDMOVFLUXO,
                                    C_RATR.CDCLASSFINA, V_VRAJBOLREC, 0);

            DELETE FROM MOVFXAJBOLR
            WHERE CDFILIBOLREC = C_RATR.CDFILIAL    AND
                  NRLANBOLREC  = C_RATR.NRLANBOLREC AND
                  CDAJUCTREC   = C_RATR.CDAJUCTREC;

         END LOOP;

         FOR C_AJCTREC IN (SELECT AJ.CDFILIAL,    AJ.NRLANCTONF,   AJ.CDAJUCTREC,
                                  AJ.CDCLASSFINA, AJ.CDEMMFAJCNTR, AJ.CDFIMFAJCNTR,
                                  AJ.DTMOVFLUXO,  AJ.IDMOVFLUXO,   AJ.VRAJUSTEREC,
                                  TA.IDAJUCTREC,  AJ.NRSEQVENREC,  AJ.NRPARCELAREC
                           FROM AJCTRECEBER AJ, TIPOAJRECEBER TA
                           WHERE (AJ.CDFILIAL     = C_BOLETREC_AB.CDFILIAL)     AND
                                 (AJ.NRLANCTONF   = C_BOLETREC_AB.NRLANCTONF)   AND
                                 (AJ.NRSEQVENREC  = C_BOLETREC_AB.NRSEQVENREC)  AND
                                 (AJ.NRPARCELAREC = C_BOLETREC_AB.NRPARCELAREC) AND
                                 (TA.CDAJUCTREC   = AJ.CDAJUCTREC)) LOOP

            IF C_AJCTREC.IDAJUCTREC = 'D' THEN
               V_VRAJUCTREC := ROUND(C_AJCTREC.VRAJUSTEREC, 2);
            ELSE
               V_VRAJUCTREC := ROUND(C_AJCTREC.VRAJUSTEREC * -1, 2);
            END IF;
            /* - DESFAZ O FLUXO DE CAIXA -------------------------- */
            ATUALIZA_FLUXO_DE_CAIXA(C_AJCTREC.CDEMMFAJCNTR, C_AJCTREC.CDFIMFAJCNTR,
                                    C_AJCTREC.DTMOVFLUXO,   C_AJCTREC.IDMOVFLUXO,
                                    C_AJCTREC.CDCLASSFINA,  V_VRAJUCTREC, 0);

            DELETE FROM AJCTRECEBER
            WHERE
               (CDFILIAL     = C_AJCTREC.CDFILIAL)     AND
               (NRLANCTONF   = C_AJCTREC.NRLANCTONF)   AND
               (NRSEQVENREC  = C_AJCTREC.NRSEQVENREC)  AND
               (NRPARCELAREC = C_AJCTREC.NRPARCELAREC);
         END LOOP;

         /* - DESFAZ O FLUXO DE CAIXA -------------------------- */
         ATUALIZA_FLUXO_DE_CAIXA(C_BOLETREC_AB.CDEMPRESA,   C_BOLETREC_AB.CDFIMOVFLREC,
                                 C_BOLETREC_AB.DTMOVFLUXO,  C_BOLETREC_AB.IDMOVFLUXO,
                                 C_BOLETREC_AB.CDCLASSFINA, C_BOLETREC_AB.VRORIGREC * -1, 0);
         DELETE FROM CONTARECEBER
         WHERE (CDFILIAL     = C_BOLETREC_AB.CDFILIAL)     AND
               (NRLANCTONF   = C_BOLETREC_AB.NRLANCTONF)   AND
               (NRSEQVENREC  = C_BOLETREC_AB.NRSEQVENREC)  AND
               (NRPARCELAREC = C_BOLETREC_AB.NRPARCELAREC);
      END LOOP;

      DELETE FROM AJBOLREC
      WHERE CDFILIAL    = C_CNTREC.CDFILIBOLREC AND
            NRLANBOLREC = C_CNTREC.NRLANBOLREC;

      DELETE FROM BOLETRECEBER
      WHERE CDFILIAL    = C_CNTREC.CDFILIBOLREC AND
            NRLANBOLREC = C_CNTREC.NRLANBOLREC;

   END LOOP;
END;
/
